Linear stability analysis
=========================

With :math:`h_b = 0`, the linear eigenproblem is

.. math:: {\mathsf{A}}\, \mathsf{\Phi} = \omega \, {\mathsf{B}}\, \mathsf{\Phi}\,,

where

.. math:: {\mathsf{A}}\equiv \mathsf{B}(\mathsf{U}\, k + \mathsf{V}\,l) + \mathsf{I}\left(k\,\mathsf{Q}_y - l\,\mathsf{Q}_x\right) + \mathsf{I}\,\delta_{\mathsf{N}\mathsf{N}}\, \mathrm{i} \,r_{ek}\,\kappa^2\,,

where :math:`\delta_{\mathsf{N}\mathsf{N}} = [0,0,\dots,0,1]\,,` and

.. math:: \mathsf{B} \equiv  \mathsf{S} - \mathsf{I} \kappa^2\,.

The growth rate is Im\ :math:`\{\omega\}`.
